summaryrefslogtreecommitdiff
path: root/cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake')
-rw-r--r--cmake/modules/FindGTK.cmake8
1 files changed, 4 insertions, 4 deletions
diff --git a/cmake/modules/FindGTK.cmake b/cmake/modules/FindGTK.cmake
index 4d66bd3a..1a32483a 100644
--- a/cmake/modules/FindGTK.cmake
+++ b/cmake/modules/FindGTK.cmake
@@ -2,8 +2,8 @@
# Once done this will define
#
# GTK_FOUND - system has GTK
# GTK2_CFLAGS - the GTK CFlags
# GTK2_LIBRARIES - Link these to use GTK
#
# Copyright 2008-2010 Pino Toscano, <pino@kde.org>
#
@@ -15,8 +15,8 @@ include(FindPackageHandleStandardArgs)
if (NOT WIN32)
find_package(PkgConfig REQUIRED)
- pkg_check_modules(GTK2 "gtk+-2.0>=2.14" "gdk-pixbuf-2.0" "gthread-2.0" "gio-2.0")
+ pkg_check_modules(GTK3 "gtk+-3.0>=3.0" "gdk-pixbuf-2.0" "gthread-2.0" "gio-2.0")
- find_package_handle_standard_args(GTK DEFAULT_MSG GTK2_LIBRARIES GTK2_CFLAGS)
+ find_package_handle_standard_args(GTK DEFAULT_MSG GTK3_LIBRARIES GTK3_CFLAGS)
endif(NOT WIN32)
@@ -2,8 +2,8 @@
#
# GTK_FOUND - system has GTK
-# GTK2_CFLAGS - the GTK CFlags
-# GTK2_LIBRARIES - Link these to use GTK
+# GTK3_CFLAGS - the GTK CFlags
+# GTK3_LIBRARIES - Link these to use GTK
#
# Copyright 2008-2010 Pino Toscano, <pino@kde.org>